@@ -69,16 +69,25 @@ class Atoms(UserList):
     def CM(self):
         """Center-of-Mass coordinates of `Atoms`.
 
+        Computes the position vector of the center-of-mass coordinates:
+
+        .. math::
+
+           \\mathbf{R}_{CM} = \\frac{1}{M}\\sum_{i=1}^{N_{\\mathrm{atoms}}}
+           m_i\\mathbf{r}_i
+
         Returns
         -------
-        ndarray
-            3-element ndarray specifying center-of-mass coordinates of `Atoms`.
+        CM : :class:`~sknano.core.math.Vector`
+            The position vector of the center of mass coordinates.
 
         """
         masses = np.asarray([self.masses])
         coords = self.coords
         MxR = masses.T * coords
-        return Vector(np.sum(MxR, axis=0) / np.sum(masses))
+        CM = Vector(np.sum(MxR, axis=0) / np.sum(masses))
+        CM.rezero()
+        return CM
 
     @property
     def M(self):
@@ -86,6 +95,27 @@ class Atoms(UserList):
         #return math.fsum(self.masses)
         return self.masses.sum()
 
+    @property
+    def centroid(self):
+        """Centroid of `Atoms`.
+
+        Computes the position vector of the centroid of the `Atoms`
+        coordinates.
+
+        .. math::
+           \\mathbf{C} =
+           \\frac{\\sum_{i=1}^{N_{\\mathrm{atoms}}}
+           m_i\\mathbf{r}_i}{\\sum_{i=1}^{N_{\\mathrm{atoms}}}m_i}
+
+        Returns
+        -------
+        C : `~sknano.core.math.Vector`
+            The position vector of the centroid coordinates.
+        """
+        C = Vector(np.mean(self.coords, axis=0))
+        C.rezero()
+        return C
+
     @property
     def coords(self):
         """Return list of `Atom` coordinates."""
@@ -116,6 +146,17 @@ class Atoms(UserList):
         """Return :math:`z` coordinates of `Atom` objects as array."""
         return self.coords[:,2]
 
+    @property
+    def inertia_tensor(self):
+        """Return the inertia tensor."""
+        Ixx = (self.masses * (self.y**2 + self.z**2)).sum()
+        Iyy = (self.masses * (self.x**2 + self.z**2)).sum()
+        Izz = (self.masses * (self.x**2 + self.y**2)).sum()
+        Ixy = Iyx = (-self.masses * self.x * self.y).sum()
+        Ixz = Izx = (-self.masses * self.x * self.z).sum()
+        Iyz = Izy = (-self.masses * self.y * self.z).sum()
+        return np.array([[Ixx, Ixy, Ixz], [Iyx, Iyy, Iyz], [Izx, Izy, Izz]])
+
     @property
     def bounds(self):
         """Return bounds of `Atoms`."""
@@ -226,6 +267,7 @@ class Atoms(UserList):
         self.rezero(epsilon=epsilon)
 
     def rezero_xyz(self, epsilon=1.0e-10):
+        """Alias for :meth:`Atoms.rezero`."""
         self.rezero(epsilon=epsilon)
 
     def rezero(self, epsilon=1.0e-10):
@@ -243,27 +285,39 @@ class Atoms(UserList):
         [atom.rezero(epsilon=epsilon) for atom in self]
 
     def rotate(self, angle=None, rot_axis=None, anchor_point=None,
-               deg2rad=False, transform_matrix=None):
-        """Rotate atom coordinates about arbitrary axis.
+               rot_point=None, from_vector=None, to_vector=None,
+               deg2rad=False, transform_matrix=None, verbose=False):
+        """Rotate `Atom` position vectors.
 
         Parameters
         ----------
         angle : float
+        rot_axis : :class:`~sknano.core.math.Vector`, optional
+        anchor_point : :class:`~sknano.core.math.Point`, optional
+        rot_point : :class:`~sknano.core.math.Point`, optional
+        from_vector, to_vector : :class:`~sknano.core.math.Vector`, optional
+        deg2rad : bool, optional
+        transform_matrix : :class:`~numpy:numpy.ndarray`
 
         """
         if transform_matrix is None:
             transform_matrix = \
-                transformation_matrix(angle, rot_axis=rot_axis,
+                transformation_matrix(angle=angle, rot_axis=rot_axis,
                                       anchor_point=anchor_point,
-                                      deg2rad=deg2rad)
+                                      rot_point=rot_point,
+                                      from_vector=from_vector,
+                                      to_vector=to_vector, deg2rad=deg2rad,
+                                      verbose=verbose)
         [atom.rotate(transform_matrix=transform_matrix) for atom in self]
 
-    def translate(self, t):
-        """Translate atom coordinates.
+    def translate(self, t, fix_anchor_points=True):
+        """Translate `Atom` position vectors by :class:`Vector` `t`.
 
         Parameters
         ----------
-        t : array_like
-            3-elment array of :math:`x,y,z` components of translation vector
+        t : :class:`Vector`
+        fix_anchor_points : bool, optional
+
         """
-        [atom.translate(t) for atom in self]
+        [atom.translate(t, fix_anchor_point=fix_anchor_points)
+         for atom in self]
