@@ -24,9 +24,17 @@ Linear algebra transforms
 .. autosummary::
    :toctree: generated/
 
+   rotate
+   scale
+   translate
+   Rx
+   Ry
+   Rz
+   reflection_matrix
    rotation_matrix
+   scaling_matrix
    transformation_matrix
-   rotation_transform
+   axis_angle_from_rotation_matrix
 
 Number theory
 ---------------
