@@ -7,8 +7,8 @@ Base structure classes (:mod:`sknano.structures._base`)
 .. currentmodule:: sknano.structures._base
 
 """
-from __future__ import absolute_import, division, print_function
-import six
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 __docformat__ = 'restructuredtext en'
 
 import numbers
@@ -19,7 +19,7 @@ __all__ = ['StructureBase']
 
 
 class StructureBase(object):
-    six.u("""Base class for creating abstract representation of nano structure.
+    """Base class for creating abstract representation of nano structure.
 
     Parameters
     ----------
@@ -32,7 +32,7 @@ class StructureBase(object):
         the carbon-carbon bond length in graphite, approximately
         :math:`\\mathrm{a}_{\\mathrm{CC}} = 1.42` \u212b
 
-    """)
+    """
     def __init__(self, element1='C', element2='C', bond=CCbond, verbose=False,
                  debug=False, **kwargs):
 
@@ -50,12 +50,12 @@ class StructureBase(object):
 
     @property
     def bond(self):
-        six.u("""Bond length in **\u212b**.""")
+        """Bond length in **\u212b**."""
         return self._bond
 
     @bond.setter
     def bond(self, value):
-        six.u("""Set bond length in **\u212b**.""")
+        """Set bond length in **\u212b**."""
         if not (isinstance(value, numbers.Real) or value > 0):
             raise TypeError('Expected a real, positive number.')
         self._bond = float(value)
