@@ -7,7 +7,8 @@ Extra helper functions (:mod:`sknano.structures._extras`)
 .. currentmodule:: sknano.structures._extras
 
 """
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 import six
 from six.moves import range
 __docformat__ = 'restructuredtext en'
@@ -45,13 +46,13 @@ attr_units['dt'] = \
     attr_units['rt'] = \
     attr_units['Ch'] = \
     attr_units['T'] = \
-    attr_units['bond'] = six.u(' \u212B')
-attr_units['chiral_angle'] = six.u('\u00b0')
+    attr_units['bond'] = ' \u212B'
+attr_units['chiral_angle'] = '\u00b0'
 
 attr_symbols = {}
-attr_symbols['t1'] = six.u('t\u2081')
-attr_symbols['t2'] = six.u('t\u2082')
-attr_symbols['chiral_angle'] = six.u('\u03b8c')
+attr_symbols['t1'] = 't\u2081'
+attr_symbols['t2'] = 't\u2082'
+attr_symbols['chiral_angle'] = '\u03b8c'
 
 attr_strfmt = {}
 attr_strfmt['Ch'] = \
@@ -81,7 +82,8 @@ def cmp_Ch(Ch1, Ch2):
         Ch1_type = get_Ch_type(Ch1)
         n2, m2 = Ch2
         Ch2_type = get_Ch_type(Ch2)
-    elif isinstance(Ch1, (str, six.text_type)) and isinstance(Ch2, (str, six.text_type)):
+    elif isinstance(Ch1, (str, six.text_type)) and \
+            isinstance(Ch2, (str, six.text_type)):
         n1, m1 = get_Ch_indices(Ch1)
         Ch1_type = get_Ch_type(Ch1)
         n2, m2 = get_Ch_indices(Ch2)
